//Source file: AccountManager.java
//Date: December 2004
//Account Management Interfaces and Data Types for 3GPP TS 29.198-11 V5.7.0

package org.csapi.jr.se.am;

/**
 * This interface represents a AccountManager.<BR>
 *
 */
public interface AccountManager extends org.csapi.jr.se.Service {

    /**
     * Adds a AccountManagerListener which is interested in events generated by the AccountManager.
     *
     * @param  accountManagerListener  A reference to the AccountManagerListener which is to be added as
     *         a listener.
     */
    void addAccountManagerListener(org.csapi.jr.se.am.AccountManagerListener accountManagerListener);

    /**
     * Removes a AccountManagerListener which is no longer interested in events generated by the AccountManager.
     *
     * @param  accountManagerListener  A reference to the AccountManagerListener which is to be removed as
     *         a listener.
     */
    void removeAccountManagerListener(org.csapi.jr.se.am.AccountManagerListener accountManagerListener);

    /**
     * Invokes the getNotification() method on the Parlay Gateway.
     */
    org.csapi.jr.se.am.ChargingEventCriteriaResult[] getNotification()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the disableNotifications() method on the Parlay Gateway.
     */
    void disableNotifications()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Creates a QueryBalance object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the QueryBalance interface.
     */
    org.csapi.jr.se.am.QueryBalance createQueryBalance();

    /**
     * Creates a Notifications object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notifications interface.
     */
    org.csapi.jr.se.am.Notifications createNotifications();

    /**
     * Creates a RetrieveTransactionHistory object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the RetrieveTransactionHistory interface.
     */
    org.csapi.jr.se.am.RetrieveTransactionHistory createRetrieveTransactionHistory();

    /**
     * Creates a Notification object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notification interface.
     */
    org.csapi.jr.se.am.Notification createNotification();

}
