//Source file: BalanceInfo.java
//Date: December 2004
//Account Management Interfaces and Data Types for 3GPP TS 29.198-11 V5.7.0

package org.csapi.jr.se.am;

/**
 * Defines the structure of data elements that specifies detailed balance info.
As an example, the currency amount composed of a Currency of EUR, a ValuePartA of 0, a ValuePartB of 10 000, and an exponent of 2 yields a currency amount of  100,00.
Valid Currencies are:
ADP, AED, AFA, ALL, AMD, ANG, AON, AOR, ARS, ATS, AUD, AWG, AZM, BAM, 
BBD, BDT, BEF, BGL, BGN, BHD, BIF, BMD, BND, BOB, BOV, BRL, BSD, BTN, 
BWP, BYB, BZD, CAD, CDF, CHF, CLF, CLP, CNY, COP, CRC, CUP, CVE, CYP, 
CZK, DEM, DJF, DKK, DOP, DZD, ECS, ECV, EEK, EGP, ERN, ESP, ETB, EUR, 
FIM, FJD, FKP, FRF, GBP, GEL, GHC, GIP, GMD, GNF, GRD, GTQ, GWP, GYD, 
HKD, HNL, HRK, HTG, HUF, IDR, IEP, ILS, INR, IQD, IRR, ISK, ITL, JMD, 
JOD, JPY, KES, KGS, KHR, KMF, KPW, KRW, KWD, KYD, KZT, LAK, LBP, LKR, 
LRD, LSL, LTL, LUF, LVL, LYD, MAD, MDL, MGF, MKD, MMK, MNT, MOP, MRO, 
MTL, MUR, MVR, MWK, MXN, MXV, MYR, MZM, NAD, NGN, NIO, NLG, NOK, NPR, 
NZD, OMR, PAB, PEN, PGK, PHP, PKR, PLN, PTE, PYG, QAR, ROL, RUB, RUR, 
RWF, SAR, SBD, SCR, SDD, SEK, SGD, SHP, SIT, SKK, SLL, SOS, SRG, STD, 
SVC, SYP, SZL, THB, TJR, TMM, TND, TOP, TPE, TRL, TTD, TWD, TZS, UAH, 
UGX, USD, USN, USS, UYU, UZS, VEB, VND, VUV, WST, XAF, XAG, XAU, XBA, 
XBB, XBC, XBD, XCD, XDR, XFO, XFU, XOF, XPD, XPF, XPT, XTS, XXX, YER, 
YUM, ZAL, ZAR, ZMK, ZRN, ZWD.
XXX is used for transactions where no currency is involved. 
 * 
 */
public final class BalanceInfo implements java.io.Serializable {

    private String currency;
    private int valuePartA;
    private int valuePartB;
    private int exponent;
    private String additionalInfo;

    /**
     * Creates a new BalanceInfo instance.
     */
    public BalanceInfo () {}

    /**
     * Creates a new BalanceInfo instance.
     * @param _currency   Currency unit according to ISO 4217: 1995
     * @param _valuePartA   This data type is identical to a TpInt32 and specifies the most significant part of the composed value. A currency amount is composed as follows:
((ValuePartA  232 + ValuePartB)  0,0001)
     * @param _valuePartB   This data type is identical to a TpInt32 and specifies the least significant part of the composed value.
     * @param _exponent   Specifies the position of the decimal point in the currency amount made up of the ValuePartA and the ValuePartB, as described above. 
For example an exponent of 4 means a pure integer value, whereas an exponent of 2 means an accuracy of 0,01.
     * @param _additionalInfo   Specifies a free format string providing additional information on the specific transaction. This could be the applicationDescription provided with the actual transaction.
     */
    public BalanceInfo (String _currency, int _valuePartA, int _valuePartB, int _exponent, String _additionalInfo) {

        this.currency = _currency;
        this.valuePartA = _valuePartA;
        this.valuePartB = _valuePartB;
        this.exponent = _exponent;
        this.additionalInfo = _additionalInfo;
    }

    /**
     * This method returns a currency.
     * 
     * @return a String value
     */
    public String getCurrency() {
        return currency;
    }

    /**
     * This method returns a valuePartA.
     * 
     * @return a int value
     */
    public int getValuePartA() {
        return valuePartA;
    }

    /**
     * This method returns a valuePartB.
     * 
     * @return a int value
     */
    public int getValuePartB() {
        return valuePartB;
    }

    /**
     * This method returns a exponent.
     * 
     * @return a int value
     */
    public int getExponent() {
        return exponent;
    }

    /**
     * This method returns a additionalInfo.
     * 
     * @return a String value
     */
    public String getAdditionalInfo() {
        return additionalInfo;
    }


    /**
     * This method sets a currency.
     */ 
    public void setCurrency(String currency) {
        this.currency = currency;
    }

    /**
     * This method sets a valuePartA.
     */ 
    public void setValuePartA(int valuePartA) {
        this.valuePartA = valuePartA;
    }

    /**
     * This method sets a valuePartB.
     */ 
    public void setValuePartB(int valuePartB) {
        this.valuePartB = valuePartB;
    }

    /**
     * This method sets a exponent.
     */ 
    public void setExponent(int exponent) {
        this.exponent = exponent;
    }

    /**
     * This method sets a additionalInfo.
     */ 
    public void setAdditionalInfo(String additionalInfo) {
        this.additionalInfo = additionalInfo;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof BalanceInfo)) {
            return false;
        } 
        BalanceInfo balanceInfo = (BalanceInfo) o;
        if ((this.currency != null) && (balanceInfo.currency != null)) {
            if(!(this.currency.equals(balanceInfo.currency)))  {
                return false;
            }
        }
        if ((this.additionalInfo != null) && (balanceInfo.additionalInfo != null)) {
            if(!(this.additionalInfo.equals(balanceInfo.additionalInfo)))  {
                return false;
            }
        }
        if(!(this.valuePartA == balanceInfo.valuePartA)) {
            return false;
        }
        if(!(this.valuePartB == balanceInfo.valuePartB)) {
            return false;
        }
        if(!(this.exponent == balanceInfo.exponent)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // BalanceInfo

