//Source file: ChargingEventName.java
//Date: December 2004
//Account Management Interfaces and Data Types for 3GPP TS 29.198-11 V5.7.0

package org.csapi.jr.se.am;

/**
 * Defines the charging event for which notifications can be requested by the application.
 *
 */
public final class ChargingEventName implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static ChargingEventName[] _array = new ChargingEventName[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private ChargingEventName(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * End user's account has been charged by an application
     */
    public static final int _AM_CHARGING =  0;

    /**
     * End user's account has been charged by an application
     */
    public static final ChargingEventName AM_CHARGING = new ChargingEventName(_AM_CHARGING);

    /**
     * End user has recharged the account
     */
    public static final int _AM_RECHARGING =  1;

    /**
     * End user has recharged the account
     */
    public static final ChargingEventName AM_RECHARGING = new ChargingEventName(_AM_RECHARGING);

    /**
     * Account balance is below the balance threshold
     */
    public static final int _AM_ACCOUNT_LOW =  2;

    /**
     * Account balance is below the balance threshold
     */
    public static final ChargingEventName AM_ACCOUNT_LOW = new ChargingEventName(_AM_ACCOUNT_LOW);

    /**
     * Account balance is at zero
     */
    public static final int _AM_ACCOUNT_ZERO =  3;

    /**
     * Account balance is at zero
     */
    public static final ChargingEventName AM_ACCOUNT_ZERO = new ChargingEventName(_AM_ACCOUNT_ZERO);

    /**
     * Account has been disabled
     */
    public static final int _AM_ACCOUNT_DISABLED =  4;

    /**
     * Account has been disabled
     */
    public static final ChargingEventName AM_ACCOUNT_DISABLED = new ChargingEventName(_AM_ACCOUNT_DISABLED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved ChargingEventName object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the ChargingEventName object
     */
    public String getValueText() {
        switch (_value) {
            case _AM_CHARGING:
                return "AM_CHARGING";
            case _AM_RECHARGING:
                return "AM_RECHARGING";
            case _AM_ACCOUNT_LOW:
                return "AM_ACCOUNT_LOW";
            case _AM_ACCOUNT_ZERO:
                return "AM_ACCOUNT_ZERO";
            case _AM_ACCOUNT_DISABLED:
                return "AM_ACCOUNT_DISABLED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static ChargingEventName getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ChargingEventName)) {
            return false;
        }
        ChargingEventName chargingEventName = (ChargingEventName) o; 
        if(!(this.getValue() == chargingEventName.getValue())) {
            return false;
        }
        if (this.hashCode() != chargingEventName.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ChargingEventName

