//Source file: Notification.java
//Date: December 2004
//Account Management Interfaces and Data Types for 3GPP TS 29.198-11 V5.7.0

package org.csapi.jr.se.am;

/**
 * This interface represents a Notification activity object.<BR>
 *
 */
public interface Notification extends org.csapi.jr.se.Activity {

    /**
     * Returns a reference to the AccountManager responsible for creation of the Notification.
     *
     * @return  A reference to the AccountManager responsible for creation of the Notification.
     */
    org.csapi.jr.se.am.AccountManager getAccountManager();

    /**
     * Adds a NotificationListener which is interested in events generated by the Notification.
     *
     * @param  notificationListener  A reference to the NotificationListener which is to be added as
     *        a listener.
     */
    void addNotificationListener(org.csapi.jr.se.am.NotificationListener notificationListener);

    /**
     * Removes a NotificationListener which is no longer interested events generated by the Notification.
     *
     * @param  notificationListener  A reference to the NotificationListener which is to be removed as
     *        a listener.
     */
    void removeNotificationListener(org.csapi.jr.se.am.NotificationListener notificationListener);

    /**
     * Invokes the createNotification() method on the Parlay Gateway.
     */
    void createNotification(
           org.csapi.jr.se.am.ChargingEventCriteria chargingEventCriteria)
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidAddressException,
       org.csapi.jr.se.InvalidCriteriaException,
       org.csapi.jr.se.InvalidEventTypeException,
       org.csapi.jr.se.UnknownSubscriberException;

    /**
     * Invokes the destroyNotification() method on the Parlay Gateway.
     */
    void destroyNotification()
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the changeNotification() method on the Parlay Gateway.
     */
    void changeNotification(
           org.csapi.jr.se.am.ChargingEventCriteria eventCriteria)
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidCriteriaException,
       org.csapi.jr.se.InvalidEventTypeException,
       org.csapi.jr.se.UnknownSubscriberException,
       org.csapi.jr.se.InvalidAddressException;
}
