//Source file: TransactionHistory.java
//Date: December 2004
//Account Management Interfaces and Data Types for 3GPP TS 29.198-11 V5.7.0

package org.csapi.jr.se.am;

/**
 * This data type is a sequence of data elements that describes the transaction history.
 * 
 */
public final class TransactionHistory implements java.io.Serializable {

    private int transactionID;
    private String timeStamp;
    private String additionalInfo;

    /**
     * Creates a new TransactionHistory instance.
     */
    public TransactionHistory () {}

    /**
     * Creates a new TransactionHistory instance.
     * @param _transactionID   Specifies the ID of the specific transaction.
     * @param _timeStamp   Specifies the date and time when the specific transaction was processed.
     * @param _additionalInfo   Specifies a free format string providing additional information on the specific transaction. This could be the applicationDescription provided with the actual transaction.
     */
    public TransactionHistory (int _transactionID, String _timeStamp, String _additionalInfo) {

        this.transactionID = _transactionID;
        this.timeStamp = _timeStamp;
        this.additionalInfo = _additionalInfo;
    }

    /**
     * This method returns a transactionID.
     * 
     * @return a int value
     */
    public int getTransactionID() {
        return transactionID;
    }

    /**
     * This method returns a timeStamp.
     * 
     * @return a String value
     */
    public String getTimeStamp() {
        return timeStamp;
    }

    /**
     * This method returns a additionalInfo.
     * 
     * @return a String value
     */
    public String getAdditionalInfo() {
        return additionalInfo;
    }


    /**
     * This method sets a transactionID.
     */ 
    public void setTransactionID(int transactionID) {
        this.transactionID = transactionID;
    }

    /**
     * This method sets a timeStamp.
     */ 
    public void setTimeStamp(String timeStamp) {
        this.timeStamp = timeStamp;
    }

    /**
     * This method sets a additionalInfo.
     */ 
    public void setAdditionalInfo(String additionalInfo) {
        this.additionalInfo = additionalInfo;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof TransactionHistory)) {
            return false;
        } 
        TransactionHistory transactionHistory = (TransactionHistory) o;
        if(!(this.transactionID == transactionHistory.transactionID)) {
            return false;
        }
        if(!(this.timeStamp == transactionHistory.timeStamp))  {
            return false;
        }
        if ((this.additionalInfo != null) && (transactionHistory.additionalInfo != null)) {
            if(!(this.additionalInfo.equals(transactionHistory.additionalInfo)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // TransactionHistory

