//Source file: TransactionHistoryStatus.java
//Date: December 2004
//Account Management Interfaces and Data Types for 3GPP TS 29.198-11 V5.7.0

package org.csapi.jr.se.am;

/**
 * Defines a status code that is reported by the Account Manager service capability feature as a result of a transaction history retrieval request. 
 *
 */
public final class TransactionHistoryStatus implements java.io.Serializable {

    private int _value;
    private static int _size = 6;
    private static TransactionHistoryStatus[] _array = new TransactionHistoryStatus[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private TransactionHistoryStatus(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * General error, unspecified.
     */
    public static final int _AM_TRANSACTION_ERROR_UNSPECIFIED =  0;

    /**
     * General error, unspecified.
     */
    public static final TransactionHistoryStatus AM_TRANSACTION_ERROR_UNSPECIFIED = new TransactionHistoryStatus(_AM_TRANSACTION_ERROR_UNSPECIFIED);

    /**
     * An invalid interval for the transaction history was specified.
     */
    public static final int _AM_TRANSACTION_INVALID_INTERVAL =  1;

    /**
     * An invalid interval for the transaction history was specified.
     */
    public static final TransactionHistoryStatus AM_TRANSACTION_INVALID_INTERVAL = new TransactionHistoryStatus(_AM_TRANSACTION_INVALID_INTERVAL);

    /**
     * No account for the specified user is known.
     */
    public static final int _AM_TRANSACTION_UNKNOWN_ACCOUNT =  2;

    /**
     * No account for the specified user is known.
     */
    public static final TransactionHistoryStatus AM_TRANSACTION_UNKNOWN_ACCOUNT = new TransactionHistoryStatus(_AM_TRANSACTION_UNKNOWN_ACCOUNT);

    /**
     * Application is not authorized to query balance.
     */
    public static final int _AM_TRANSACTION_UNAUTHORIZED_APPLICATION =  3;

    /**
     * Application is not authorized to query balance.
     */
    public static final TransactionHistoryStatus AM_TRANSACTION_UNAUTHORIZED_APPLICATION = new TransactionHistoryStatus(_AM_TRANSACTION_UNAUTHORIZED_APPLICATION);

    /**
     * A processing error occurred while compiling the transaction history.
     */
    public static final int _AM_TRANSACTION_PROCESSING_ERROR =  4;

    /**
     * A processing error occurred while compiling the transaction history.
     */
    public static final TransactionHistoryStatus AM_TRANSACTION_PROCESSING_ERROR = new TransactionHistoryStatus(_AM_TRANSACTION_PROCESSING_ERROR);

    /**
     * System failure. The request could not be handled.
     */
    public static final int _AM_TRANSACTION_SYSTEM_FAILURE =  5;

    /**
     * System failure. The request could not be handled.
     */
    public static final TransactionHistoryStatus AM_TRANSACTION_SYSTEM_FAILURE = new TransactionHistoryStatus(_AM_TRANSACTION_SYSTEM_FAILURE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved TransactionHistoryStatus object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the TransactionHistoryStatus object
     */
    public String getValueText() {
        switch (_value) {
            case _AM_TRANSACTION_ERROR_UNSPECIFIED:
                return "AM_TRANSACTION_ERROR_UNSPECIFIED";
            case _AM_TRANSACTION_INVALID_INTERVAL:
                return "AM_TRANSACTION_INVALID_INTERVAL";
            case _AM_TRANSACTION_UNKNOWN_ACCOUNT:
                return "AM_TRANSACTION_UNKNOWN_ACCOUNT";
            case _AM_TRANSACTION_UNAUTHORIZED_APPLICATION:
                return "AM_TRANSACTION_UNAUTHORIZED_APPLICATION";
            case _AM_TRANSACTION_PROCESSING_ERROR:
                return "AM_TRANSACTION_PROCESSING_ERROR";
            case _AM_TRANSACTION_SYSTEM_FAILURE:
                return "AM_TRANSACTION_SYSTEM_FAILURE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 5
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static TransactionHistoryStatus getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof TransactionHistoryStatus)) {
            return false;
        }
        TransactionHistoryStatus transactionHistoryStatus = (TransactionHistoryStatus) o; 
        if(!(this.getValue() == transactionHistoryStatus.getValue())) {
            return false;
        }
        if (this.hashCode() != transactionHistoryStatus.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // TransactionHistoryStatus

